@@ -1,6 +1,6 @@
 import { Program } from "@project-serum/anchor";
 import { TransactionInstruction } from "@solana/web3.js";
-import { ListProgram } from "../idl";
+import { Indexer } from "../idl";
 import { Account } from "../account";
 
 import { CreateList, CreateListArgs } from "./createList";
@@ -10,7 +10,7 @@ import { PopElement, PopElementArgs } from "./popElement";
 
 export class Instruction {
   private account: Account;
-  private program: Program<ListProgram>;
+  private program: Program<Indexer>;
 
   public createList: (args: CreateListArgs) => Promise<TransactionInstruction>;
 
@@ -22,7 +22,7 @@ export class Instruction {
 
   public popElement: (args: PopElementArgs) => Promise<TransactionInstruction>;
 
-  constructor(account: Account, program: Program<ListProgram>) {
+  constructor(account: Account, program: Program<Indexer>) {
     this.account = account;
     this.program = program;
 
