@@ -3,10 +3,10 @@ pub mod state;
 
 use {anchor_lang::prelude::*, instructions::*};
 
-declare_id!("DBMi4GBjiX15vCMVj93uB7JYM9LU6rCaZJraVKM6XgZi");
+declare_id!("4jnuXU4zsBavciDpTNmJ8dtwMBSkhKn2EBCiE9Rrv8uQ");
 
 #[program]
-pub mod list_program {
+pub mod indexer {
     use super::*;
 
     pub fn create_list(ctx: Context<CreateList>, bump: u8) -> ProgramResult {
